@@ -3,13 +3,13 @@ from messytables.util import offset_processor
 from messytables.headers import headers_guess, headers_processor, headers_make_unique
 from messytables.types import type_guess, types_processor
 from messytables.types import StringType, IntegerType, FloatType, \
-        DecimalType, DateType
+        DecimalType, DateType, DateUtilType
 
 from messytables.core import Cell, TableSet, RowSet, seekable_stream
 from messytables.commas import CSVTableSet, CSVRowSet
 from messytables.excel import XLSTableSet, XLSRowSet
 from messytables.excelx import XLSXTableSet, XLSXRowSet
 from messytables.zip import ZIPTableSet
-from messytables.any import AnyTableSet
+from messytables.any import any_tableset, AnyTableSet
 
 from messytables.jts import rowset_as_jts, headers_and_typed_as_jts
